@@ -1,6 +1,6 @@
 from torchvision.datasets import *
 from torchvision.datasets.vision import StandardTransform
 
-from .oxford_iiit_cat_dog import OxfordCatDog
-from .oxford_iiit_pet import OxfordIIITPet
+from .oxford_iiit_pet_plus import OxfordIIITPetPlus
+from .stack import StackDataset
 from .stanford_dogs import StanfordDogs
